/*
Copyright (c) 2003 Forward Computing and Control Pty. Ltd.
NSW. Australia,  www.forward.com.au
All rights reserved.

Redistribution of the source of this package, with or without
modification, is NOT permitted.

Redistribution of the compiled java .class files of this package, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions in compiled java .class form must reproduce the above
   copyright notice, this list of conditions and the following disclaimer
   in the documentation and/or other materials provided with the distribution.

2. If the software is modified, the compiled java .class distribution must
   include, in the documentation and/or other materials provided with the 
   distribution, a statement that the software has been modified and
   identify the person who was responsable for the modifications.  

3. Neither the name of the author nor Forward Computing and Control may be 
   used to endorse or promote products derived from this software
   without specific prior written permission.

4.  All advertising materials mentioning features or use of this
    software must display the following acknowledgment: 
    "This product includes software developed by Matthew Ford
     and Forward Computing and Control Pty. Ltd. 
    (http://www.forward.com.au)."


THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/

package au.com.forward.test;

import java.awt.Rectangle;
import javax.swing.JFrame;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import au.com.forward.inputTipsManager.*;
import java.awt.Container;
import javax.swing.JViewport;

/**
 *
 * @author  Matthew Ford
 */
public class InputTipsTestScreen extends javax.swing.JPanel {
  
  /** Creates new form InputTipsTestScreen */
  public InputTipsTestScreen() {
    initComponents();
    doSetup();
  }
  
  protected void doSetup() {
    editTestPanel.add(new InputTipsEditorTestPanel());
    textArea.setText(
"Instructions:\n"+
"The Key Listener  listens to the keystrokes and rejects non-digits.\n"+
"The Focus Listener  allows you to enter data but when you go to move focus it checks for a invalid numbers and prevents the focus changing.\n"+
"The Input Verifier is similar the Focus Listener, but uses the JComponent.setInputVerifier() to set an InputVerifier which is called on attempting focus change.\n"+
"The Model uses a modified Document which over-rides insert() and remove() to check for valid numbers.\n"+
"The Combo box version use the same checks but applied to combo boxes. Note the differences in the way the selection of an invalid item in the list is handled.\n"+
"Try pasting an invalid entry from the clipboard into each example and see what happens.\n"+
"\n"+            
"The table below illustrates how you can display a user input message next to a cell in a table. Here we just display the row number of selection.\n"+
"When showing the table Input Tip, no focus listener has been added to the table tip to remove it when the table looses focus, but notice how the table Input Tip interacts with the Focus and Verify Input Tips when you switch focus to the table."
            );

    // add selection listeners for rows
    table.getSelectionModel().addListSelectionListener(new TableSelectionListener());
  }

  protected class TableSelectionListener implements ListSelectionListener {
        /**
         * Called whenever the value of the selection changes.
         * @param e the event that characterizes the change.
         */
        public void valueChanged(ListSelectionEvent e) {
            int selectedRow = table.getSelectedRow();
            int selectedColumn = table.getSelectedColumn();
            if (e.getValueIsAdjusting()) {
                return;
            }
            Rectangle cellRect = table.getCellRect(selectedRow,selectedColumn, true);
						String tip = "<HTML>" + "Row "+selectedRow+" has been selected.";
            InputTipsManager.sharedInstance().showInputTip(table,tip, false, cellRect);
            }
        }
  
  
  /**
   * @param args the command line arguments
   */
  public static void main(String args[]) {
    JFrame mainFrame = new JFrame();
    InputTipsTestScreen screen = new InputTipsTestScreen();
		mainFrame.setTitle("InputTipsManager Test Screen");
    mainFrame.setSize(800, 600);
    
    mainFrame.add(screen);
    mainFrame.setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
    mainFrame.addWindowListener(new java.awt.event.WindowAdapter() {
      public void windowClosed(java.awt.event.WindowEvent evt) {
        System.exit(0);
      }
    });
    mainFrame.setVisible(true);
  }
 
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
  private void initComponents() {
    java.awt.GridBagConstraints gridBagConstraints;

    editTestPanel = new javax.swing.JPanel();
    tableScrollPane = new javax.swing.JScrollPane();
    table = new javax.swing.JTable();
    textArea = new javax.swing.JTextArea();

    setLayout(new java.awt.GridBagLayout());

    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
    add(editTestPanel, gridBagConstraints);

    table.setModel(new javax.swing.table.DefaultTableModel(
      new Object [][] {
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null},
        {null, null, null, null, null, null, null, null, null, null}
      },
      new String [] {
        "Title 1", "Title 2", "Title 3", "Title 4", "Title 5", "Title 6", "Title 7", "Title 8", "Title 9", "Title 10"
      }
    ) {
      boolean[] canEdit = new boolean [] {
        false, false, false, false, true, true, true, true, true, true
      };

      public boolean isCellEditable(int rowIndex, int columnIndex) {
        return canEdit [columnIndex];
      }
    });
    tableScrollPane.setViewportView(table);

    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 0;
    gridBagConstraints.gridy = 1;
    gridBagConstraints.gridwidth = 2;
    gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.weighty = 1.0;
    add(tableScrollPane, gridBagConstraints);

    textArea.setLineWrap(true);
    textArea.setWrapStyleWord(true);
    textArea.setFocusable(false);
    textArea.setRequestFocusEnabled(false);
    textArea.setVerifyInputWhenFocusTarget(false);
    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 4);
    add(textArea, gridBagConstraints);

  }
  // </editor-fold>//GEN-END:initComponents
  
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JPanel editTestPanel;
  private javax.swing.JTable table;
  private javax.swing.JScrollPane tableScrollPane;
  private javax.swing.JTextArea textArea;
  // End of variables declaration//GEN-END:variables
  
}
